Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.kernel > #1303661

[PATCH 1/5] cfq-iosched: Don't group_idle if cfqq has big thinktime

From Jan Kara <jack@suse.cz>
Newsgroups linux.kernel
Subject [PATCH 1/5] cfq-iosched: Don't group_idle if cfqq has big thinktime
Date 2016-01-07 16:30 +0100
Message-ID <qOkFJ-1wu-39@gated-at.bofh.it> (permalink)
References <qOkFI-1wu-11@gated-at.bofh.it>
Organization linux.* mail to news gateway

Show all headers | View raw


From: Jan Kara <jack@suse.com>

There is no point in idling on a cfq group if the only cfq queue that is
there has too big thinktime.

Signed-off-by: Jan Kara <jack@suse.com>
---
 block/cfq-iosched.c | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/block/cfq-iosched.c b/block/cfq-iosched.c
index 1f9093e901da..fcef1786edf3 100644
--- a/block/cfq-iosched.c
+++ b/block/cfq-iosched.c
@@ -2897,6 +2897,7 @@ static bool cfq_should_idle(struct cfq_data *cfqd, struct cfq_queue *cfqq)
 static void cfq_arm_slice_timer(struct cfq_data *cfqd)
 {
 	struct cfq_queue *cfqq = cfqd->active_queue;
+	struct cfq_rb_root *st = cfqq->service_tree;
 	struct cfq_io_cq *cic;
 	unsigned long sl, group_idle = 0;
 
@@ -2947,8 +2948,13 @@ static void cfq_arm_slice_timer(struct cfq_data *cfqd)
 		return;
 	}
 
-	/* There are other queues in the group, don't do group idle */
-	if (group_idle && cfqq->cfqg->nr_cfqq > 1)
+	/*
+	 * There are other queues in the group or this is the only group and
+	 * it has too big thinktime, don't do group idle.
+	 */
+	if (group_idle &&
+	    (cfqq->cfqg->nr_cfqq > 1 ||
+	     !cfq_io_thinktime_big(cfqd, &st->ttime, true)))
 		return;
 
 	cfq_mark_cfqq_wait_request(cfqq);
-- 
2.6.2

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Back to linux.kernel | Previous | NextNext in thread | Find similar | Unroll thread


Thread

[PATCH 1/5] cfq-iosched: Don't group_idle if cfqq has big thinktime Jan Kara <jack@suse.cz> - 2016-01-07 16:30 +0100
  Re: [PATCH 1/5] cfq-iosched: Don't group_idle if cfqq has big  thinktime Tejun Heo <tj@kernel.org> - 2016-01-08 18:00 +0100
    Re: [PATCH 1/5] cfq-iosched: Don't group_idle if cfqq has big  thinktime Jan Kara <jack@suse.cz> - 2016-01-11 16:50 +0100

csiph-web